/********************************************************************************
** Form generated from reading UI file 'quickbeamerdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QUICKBEAMERDIALOG_H
#define UI_QUICKBEAMERDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_QuickBeamerDialog
{
public:
    QGridLayout *gridLayout_2;
    QGridLayout *gridLayout;
    QLabel *labelTheme;
    QLabel *labelTitle;
    QLineEdit *lineEditAuthor;
    QLabel *labelEncoding;
    QLabel *labelSize;
    QLineEdit *lineEditTitle;
    QComboBox *comboBoxSize;
    QLabel *labelAuthor;
    QListWidget *listWidgetBabel;
    QCheckBox *checkBoxBabel;
    QComboBox *comboBoxEncoding;
    QComboBox *comboBoxTheme;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *QuickBeamerDialog)
    {
        if (QuickBeamerDialog->objectName().isEmpty())
            QuickBeamerDialog->setObjectName("QuickBeamerDialog");
        QuickBeamerDialog->resize(940, 474);
        gridLayout_2 = new QGridLayout(QuickBeamerDialog);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        labelTheme = new QLabel(QuickBeamerDialog);
        labelTheme->setObjectName("labelTheme");

        gridLayout->addWidget(labelTheme, 0, 0, 1, 1);

        labelTitle = new QLabel(QuickBeamerDialog);
        labelTitle->setObjectName("labelTitle");

        gridLayout->addWidget(labelTitle, 5, 0, 1, 1);

        lineEditAuthor = new QLineEdit(QuickBeamerDialog);
        lineEditAuthor->setObjectName("lineEditAuthor");

        gridLayout->addWidget(lineEditAuthor, 4, 1, 1, 1);

        labelEncoding = new QLabel(QuickBeamerDialog);
        labelEncoding->setObjectName("labelEncoding");

        gridLayout->addWidget(labelEncoding, 3, 0, 1, 1);

        labelSize = new QLabel(QuickBeamerDialog);
        labelSize->setObjectName("labelSize");

        gridLayout->addWidget(labelSize, 1, 0, 1, 1);

        lineEditTitle = new QLineEdit(QuickBeamerDialog);
        lineEditTitle->setObjectName("lineEditTitle");

        gridLayout->addWidget(lineEditTitle, 5, 1, 1, 1);

        comboBoxSize = new QComboBox(QuickBeamerDialog);
        comboBoxSize->setObjectName("comboBoxSize");

        gridLayout->addWidget(comboBoxSize, 1, 1, 1, 1);

        labelAuthor = new QLabel(QuickBeamerDialog);
        labelAuthor->setObjectName("labelAuthor");

        gridLayout->addWidget(labelAuthor, 4, 0, 1, 1);

        listWidgetBabel = new QListWidget(QuickBeamerDialog);
        listWidgetBabel->setObjectName("listWidgetBabel");

        gridLayout->addWidget(listWidgetBabel, 6, 1, 1, 1);

        checkBoxBabel = new QCheckBox(QuickBeamerDialog);
        checkBoxBabel->setObjectName("checkBoxBabel");

        gridLayout->addWidget(checkBoxBabel, 6, 0, 1, 1);

        comboBoxEncoding = new QComboBox(QuickBeamerDialog);
        comboBoxEncoding->setObjectName("comboBoxEncoding");

        gridLayout->addWidget(comboBoxEncoding, 3, 1, 1, 1);

        comboBoxTheme = new QComboBox(QuickBeamerDialog);
        comboBoxTheme->setObjectName("comboBoxTheme");

        gridLayout->addWidget(comboBoxTheme, 0, 1, 1, 1);


        gridLayout_2->addLayout(gridLayout, 0, 0, 1, 1);

        scrollArea = new QScrollArea(QuickBeamerDialog);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setMinimumSize(QSize(520, 0));
        scrollArea->setMaximumSize(QSize(520, 16777215));
        scrollArea->setAutoFillBackground(false);
        scrollArea->setWidgetResizable(false);
        scrollArea->setAlignment(Qt::AlignCenter);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 510, 474));
        scrollArea->setWidget(scrollAreaWidgetContents);

        gridLayout_2->addWidget(scrollArea, 0, 1, 1, 1);

        buttonBox = new QDialogButtonBox(QuickBeamerDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout_2->addWidget(buttonBox, 1, 0, 1, 2);

        QWidget::setTabOrder(comboBoxTheme, comboBoxSize);
        QWidget::setTabOrder(comboBoxSize, comboBoxEncoding);
        QWidget::setTabOrder(comboBoxEncoding, lineEditAuthor);
        QWidget::setTabOrder(lineEditAuthor, lineEditTitle);
        QWidget::setTabOrder(lineEditTitle, listWidgetBabel);
        QWidget::setTabOrder(listWidgetBabel, checkBoxBabel);
        QWidget::setTabOrder(checkBoxBabel, buttonBox);
        QWidget::setTabOrder(buttonBox, scrollArea);

        retranslateUi(QuickBeamerDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, QuickBeamerDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, QuickBeamerDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(QuickBeamerDialog);
    } // setupUi

    void retranslateUi(QDialog *QuickBeamerDialog)
    {
        QuickBeamerDialog->setWindowTitle(QCoreApplication::translate("QuickBeamerDialog", "Dialog", nullptr));
        labelTheme->setText(QCoreApplication::translate("QuickBeamerDialog", "Theme", nullptr));
        labelTitle->setText(QCoreApplication::translate("QuickBeamerDialog", "Title", nullptr));
        labelEncoding->setText(QCoreApplication::translate("QuickBeamerDialog", "Encoding", nullptr));
        labelSize->setText(QCoreApplication::translate("QuickBeamerDialog", "Typeface Size", nullptr));
        labelAuthor->setText(QCoreApplication::translate("QuickBeamerDialog", "Author", nullptr));
        checkBoxBabel->setText(QCoreApplication::translate("QuickBeamerDialog", "babel Package", nullptr));
    } // retranslateUi

};

namespace Ui {
    class QuickBeamerDialog: public Ui_QuickBeamerDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QUICKBEAMERDIALOG_H
