/****************************************************************************
** Meta object code from reading C++ file 'latextokens.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../texstudio-4.9.5/src/latexparser/latextokens.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'latextokens.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14EnumsTokenTypeE_t {};
} // unnamed namespace

template <> constexpr inline auto EnumsTokenType::qt_create_metaobjectdata<qt_meta_tag_ZN14EnumsTokenTypeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EnumsTokenType",
        "TokenType",
        "none",
        "word",
        "command",
        "braces",
        "bracket",
        "squareBracket",
        "openBrace",
        "openBracket",
        "openSquare",
        "less",
        "closeBrace",
        "closeBracket",
        "closeSquareBracket",
        "greater",
        "math",
        "comment",
        "commandUnknown",
        "label",
        "bibItem",
        "file",
        "imagefile",
        "bibfile",
        "keyValArg",
        "keyVal_key",
        "keyVal_val",
        "list",
        "text",
        "env",
        "beginEnv",
        "def",
        "labelRef",
        "package",
        "width",
        "placement",
        "colDef",
        "title",
        "shorttitle",
        "todo",
        "url",
        "documentclass",
        "beamertheme",
        "packageoption",
        "color",
        "verbatimStart",
        "verbatimStop",
        "verbatim",
        "symbol",
        "punctuation",
        "number",
        "generalArg",
        "defArgNumber",
        "optionalArgDefinition",
        "definition",
        "defWidth",
        "labelRefList",
        "formula",
        "newTheorem",
        "newBibItem",
        "overlay",
        "overlayRegion",
        "defXparseArg",
        "defSpecialArg",
        "specialArg",
        "_end"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'TokenType'
        QtMocHelpers::EnumData<enum TokenType>(1, 1, QMC::EnumFlags{}).add({
            {    2, TokenType::none },
            {    3, TokenType::word },
            {    4, TokenType::command },
            {    5, TokenType::braces },
            {    6, TokenType::bracket },
            {    7, TokenType::squareBracket },
            {    8, TokenType::openBrace },
            {    9, TokenType::openBracket },
            {   10, TokenType::openSquare },
            {   11, TokenType::less },
            {   12, TokenType::closeBrace },
            {   13, TokenType::closeBracket },
            {   14, TokenType::closeSquareBracket },
            {   15, TokenType::greater },
            {   16, TokenType::math },
            {   17, TokenType::comment },
            {   18, TokenType::commandUnknown },
            {   19, TokenType::label },
            {   20, TokenType::bibItem },
            {   21, TokenType::file },
            {   22, TokenType::imagefile },
            {   23, TokenType::bibfile },
            {   24, TokenType::keyValArg },
            {   25, TokenType::keyVal_key },
            {   26, TokenType::keyVal_val },
            {   27, TokenType::list },
            {   28, TokenType::text },
            {   29, TokenType::env },
            {   30, TokenType::beginEnv },
            {   31, TokenType::def },
            {   32, TokenType::labelRef },
            {   33, TokenType::package },
            {   34, TokenType::width },
            {   35, TokenType::placement },
            {   36, TokenType::colDef },
            {   37, TokenType::title },
            {   38, TokenType::shorttitle },
            {   39, TokenType::todo },
            {   40, TokenType::url },
            {   41, TokenType::documentclass },
            {   42, TokenType::beamertheme },
            {   43, TokenType::packageoption },
            {   44, TokenType::color },
            {   45, TokenType::verbatimStart },
            {   46, TokenType::verbatimStop },
            {   47, TokenType::verbatim },
            {   48, TokenType::symbol },
            {   49, TokenType::punctuation },
            {   50, TokenType::number },
            {   51, TokenType::generalArg },
            {   52, TokenType::defArgNumber },
            {   53, TokenType::optionalArgDefinition },
            {   54, TokenType::definition },
            {   55, TokenType::defWidth },
            {   56, TokenType::labelRefList },
            {   57, TokenType::formula },
            {   58, TokenType::newTheorem },
            {   59, TokenType::newBibItem },
            {   60, TokenType::overlay },
            {   61, TokenType::overlayRegion },
            {   62, TokenType::defXparseArg },
            {   63, TokenType::defSpecialArg },
            {   64, TokenType::specialArg },
            {   65, TokenType::_end },
        }),
    };
    return QtMocHelpers::metaObjectData<EnumsTokenType, qt_meta_tag_ZN14EnumsTokenTypeE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EnumsTokenType::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14EnumsTokenTypeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14EnumsTokenTypeE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14EnumsTokenTypeE_t>.metaTypes,
    nullptr
} };

QT_WARNING_POP
