/****************************************************************************
** Meta object code from reading C++ file 'qdocument.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../texstudio-4.9.5/src/qcodeedit/lib/document/qdocument.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qdocument.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9QDocumentE_t {};
} // unnamed namespace

template <> constexpr inline auto QDocument::qt_create_metaobjectdata<qt_meta_tag_ZN9QDocumentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QDocument",
        "cleanChanged",
        "",
        "m",
        "undoAvailable",
        "y",
        "redoAvailable",
        "formatsChanged",
        "contentsChanged",
        "fontChanged",
        "QFont",
        "formatsChange",
        "line",
        "lines",
        "contentsChange",
        "changedText",
        "startLine",
        "startCol",
        "endLine",
        "endCol",
        "text",
        "widthChanged",
        "width",
        "heightChanged",
        "height",
        "sizeChanged",
        "QSize",
        "s",
        "lineCountChanged",
        "n",
        "visualLineCountChanged",
        "lineDeleted",
        "QDocumentLineHandle*",
        "h",
        "hint",
        "lineRemoved",
        "linesRemoved",
        "count",
        "markChanged",
        "l",
        "on",
        "lineEndingChanged",
        "lineEnding",
        "slowOperationStarted",
        "slowOperationEnded",
        "bookmarkRemoved",
        "dlh",
        "bookmarkAdded",
        "nr",
        "clear",
        "undo",
        "redo",
        "clearUndo",
        "setClean",
        "highlight",
        "print",
        "QPrinter*",
        "p",
        "clearWidthConstraint",
        "setWidthConstraint",
        "markFormatCacheDirty",
        "mode",
        "removeTrailing",
        "preserveIndent",
        "textLines",
        "setText",
        "allowUndo",
        "notVisible",
        "lineEndingString",
        "canUndo",
        "canRedo",
        "lineCount",
        "visualLineCount",
        "cursor",
        "QDocumentCursor",
        "column",
        "lineTo",
        "columnTo",
        "beginMacro",
        "endMacro",
        "hasMacros",
        "beginDelayedUpdateBlock",
        "endDelayedUpdateBlock",
        "expand",
        "collapse",
        "expandParents",
        "foldBlockAt",
        "unFold"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'cleanChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'undoAvailable'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'redoAvailable'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'formatsChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contentsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontChanged'
        QtMocHelpers::SignalData<void(QFont)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Signal 'formatsChange'
        QtMocHelpers::SignalData<void(int, int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 }, { QMetaType::Int, 13 },
        }}),
        // Signal 'contentsChange'
        QtMocHelpers::SignalData<void(int, int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 }, { QMetaType::Int, 13 },
        }}),
        // Signal 'changedText'
        QtMocHelpers::SignalData<void(int, int, int, int, const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 19 },
            { QMetaType::QString, 20 },
        }}),
        // Signal 'widthChanged'
        QtMocHelpers::SignalData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Signal 'heightChanged'
        QtMocHelpers::SignalData<void(int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 24 },
        }}),
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void(const QSize &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Signal 'lineCountChanged'
        QtMocHelpers::SignalData<void(int)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Signal 'visualLineCountChanged'
        QtMocHelpers::SignalData<void(int)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Signal 'lineDeleted'
        QtMocHelpers::SignalData<void(QDocumentLineHandle *, int)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { QMetaType::Int, 34 },
        }}),
        // Signal 'lineDeleted'
        QtMocHelpers::SignalData<void(QDocumentLineHandle *)>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Signal 'lineRemoved'
        QtMocHelpers::SignalData<void(QDocumentLineHandle *)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Signal 'linesRemoved'
        QtMocHelpers::SignalData<void(QDocumentLineHandle *, int, int)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { QMetaType::Int, 34 }, { QMetaType::Int, 37 },
        }}),
        // Signal 'markChanged'
        QtMocHelpers::SignalData<void(QDocumentLineHandle *, int, bool)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 39 }, { QMetaType::Int, 3 }, { QMetaType::Bool, 40 },
        }}),
        // Signal 'lineEndingChanged'
        QtMocHelpers::SignalData<void(int)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 42 },
        }}),
        // Signal 'slowOperationStarted'
        QtMocHelpers::SignalData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'slowOperationEnded'
        QtMocHelpers::SignalData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bookmarkRemoved'
        QtMocHelpers::SignalData<void(QDocumentLineHandle *)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 46 },
        }}),
        // Signal 'bookmarkAdded'
        QtMocHelpers::SignalData<void(QDocumentLineHandle *, int)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 46 }, { QMetaType::Int, 48 },
        }}),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'undo'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'redo'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearUndo'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setClean'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'highlight'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'print'
        QtMocHelpers::SlotData<void(QPrinter *)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 56, 57 },
        }}),
        // Slot 'clearWidthConstraint'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setWidthConstraint'
        QtMocHelpers::SlotData<void(int)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'markFormatCacheDirty'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'text'
        QtMocHelpers::MethodData<QString(int) const>(20, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 61 },
        }}),
        // Method 'text'
        QtMocHelpers::MethodData<QString(bool, bool) const>(20, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Bool, 62 }, { QMetaType::Bool, 63 },
        }}),
        // Method 'text'
        QtMocHelpers::MethodData<QString(bool) const>(20, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::Bool, 62 },
        }}),
        // Method 'text'
        QtMocHelpers::MethodData<QString() const>(20, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString),
        // Method 'textLines'
        QtMocHelpers::MethodData<QStringList() const>(64, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'setText'
        QtMocHelpers::MethodData<void(const QString &, bool, bool)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::Bool, 66 }, { QMetaType::Bool, 67 },
        }}),
        // Method 'setText'
        QtMocHelpers::MethodData<void(const QString &, bool)>(65, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::Bool, 66 },
        }}),
        // Method 'lineEndingString'
        QtMocHelpers::MethodData<QString() const>(68, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'canUndo'
        QtMocHelpers::MethodData<bool() const>(69, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'canRedo'
        QtMocHelpers::MethodData<bool() const>(70, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'lineCount'
        QtMocHelpers::MethodData<int() const>(71, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'visualLineCount'
        QtMocHelpers::MethodData<int() const>(72, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'cursor'
        QtMocHelpers::MethodData<QDocumentCursor(int, int, int, int) const>(73, 2, QMC::AccessPublic, 0x80000000 | 74, {{
            { QMetaType::Int, 12 }, { QMetaType::Int, 75 }, { QMetaType::Int, 76 }, { QMetaType::Int, 77 },
        }}),
        // Method 'cursor'
        QtMocHelpers::MethodData<QDocumentCursor(int, int, int) const>(73, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 74, {{
            { QMetaType::Int, 12 }, { QMetaType::Int, 75 }, { QMetaType::Int, 76 },
        }}),
        // Method 'cursor'
        QtMocHelpers::MethodData<QDocumentCursor(int, int) const>(73, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 74, {{
            { QMetaType::Int, 12 }, { QMetaType::Int, 75 },
        }}),
        // Method 'cursor'
        QtMocHelpers::MethodData<QDocumentCursor(int) const>(73, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 74, {{
            { QMetaType::Int, 12 },
        }}),
        // Method 'beginMacro'
        QtMocHelpers::MethodData<void()>(78, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'endMacro'
        QtMocHelpers::MethodData<void()>(79, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'hasMacros'
        QtMocHelpers::MethodData<bool()>(80, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'beginDelayedUpdateBlock'
        QtMocHelpers::MethodData<void()>(81, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'endDelayedUpdateBlock'
        QtMocHelpers::MethodData<void()>(82, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'expand'
        QtMocHelpers::MethodData<void(int)>(83, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Method 'collapse'
        QtMocHelpers::MethodData<void(int)>(84, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Method 'expandParents'
        QtMocHelpers::MethodData<void(int)>(85, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Method 'foldBlockAt'
        QtMocHelpers::MethodData<void(bool, int)>(86, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 87 }, { QMetaType::Int, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QDocument, qt_meta_tag_ZN9QDocumentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QDocument::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QDocumentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QDocumentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9QDocumentE_t>.metaTypes,
    nullptr
} };

void QDocument::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QDocument *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->cleanChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->undoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->redoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->formatsChanged(); break;
        case 4: _t->contentsChanged(); break;
        case 5: _t->fontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 6: _t->formatsChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->contentsChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 8: _t->changedText((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 9: _t->widthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->heightChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->sizeChanged((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 12: _t->lineCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->visualLineCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->lineDeleted((*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 15: _t->lineDeleted((*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[1]))); break;
        case 16: _t->lineRemoved((*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[1]))); break;
        case 17: _t->linesRemoved((*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 18: _t->markChanged((*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 19: _t->lineEndingChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->slowOperationStarted(); break;
        case 21: _t->slowOperationEnded(); break;
        case 22: _t->bookmarkRemoved((*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[1]))); break;
        case 23: _t->bookmarkAdded((*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 24: _t->clear(); break;
        case 25: _t->undo(); break;
        case 26: _t->redo(); break;
        case 27: _t->clearUndo(); break;
        case 28: _t->setClean(); break;
        case 29: _t->highlight(); break;
        case 30: _t->print((*reinterpret_cast<std::add_pointer_t<QPrinter*>>(_a[1]))); break;
        case 31: _t->clearWidthConstraint(); break;
        case 32: _t->setWidthConstraint((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->markFormatCacheDirty(); break;
        case 34: { QString _r = _t->text((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 35: { QString _r = _t->text((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 36: { QString _r = _t->text((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 37: { QString _r = _t->text();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 38: { QStringList _r = _t->textLines();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 39: _t->setText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 40: _t->setText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 41: { QString _r = _t->lineEndingString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 42: { bool _r = _t->canUndo();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 43: { bool _r = _t->canRedo();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 44: { int _r = _t->lineCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 45: { int _r = _t->visualLineCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 46: { QDocumentCursor _r = _t->cursor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDocumentCursor*>(_a[0]) = std::move(_r); }  break;
        case 47: { QDocumentCursor _r = _t->cursor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDocumentCursor*>(_a[0]) = std::move(_r); }  break;
        case 48: { QDocumentCursor _r = _t->cursor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDocumentCursor*>(_a[0]) = std::move(_r); }  break;
        case 49: { QDocumentCursor _r = _t->cursor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDocumentCursor*>(_a[0]) = std::move(_r); }  break;
        case 50: _t->beginMacro(); break;
        case 51: _t->endMacro(); break;
        case 52: { bool _r = _t->hasMacros();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 53: _t->beginDelayedUpdateBlock(); break;
        case 54: _t->endDelayedUpdateBlock(); break;
        case 55: _t->expand((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 56: _t->collapse((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 57: _t->expandParents((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 58: _t->foldBlockAt((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(bool )>(_a, &QDocument::cleanChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(bool )>(_a, &QDocument::undoAvailable, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(bool )>(_a, &QDocument::redoAvailable, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)()>(_a, &QDocument::formatsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)()>(_a, &QDocument::contentsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(QFont )>(_a, &QDocument::fontChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(int , int )>(_a, &QDocument::formatsChange, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(int , int )>(_a, &QDocument::contentsChange, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(int , int , int , int , const QString & )>(_a, &QDocument::changedText, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(int )>(_a, &QDocument::widthChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(int )>(_a, &QDocument::heightChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(const QSize & )>(_a, &QDocument::sizeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(int )>(_a, &QDocument::lineCountChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(int )>(_a, &QDocument::visualLineCountChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(QDocumentLineHandle * , int )>(_a, &QDocument::lineDeleted, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(QDocumentLineHandle * )>(_a, &QDocument::lineRemoved, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(QDocumentLineHandle * , int , int )>(_a, &QDocument::linesRemoved, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(QDocumentLineHandle * , int , bool )>(_a, &QDocument::markChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(int )>(_a, &QDocument::lineEndingChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)()>(_a, &QDocument::slowOperationStarted, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)()>(_a, &QDocument::slowOperationEnded, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(QDocumentLineHandle * )>(_a, &QDocument::bookmarkRemoved, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDocument::*)(QDocumentLineHandle * , int )>(_a, &QDocument::bookmarkAdded, 23))
            return;
    }
}

const QMetaObject *QDocument::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QDocument::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QDocumentE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QDocument::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 59)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 59;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 59)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 59;
    }
    return _id;
}

// SIGNAL 0
void QDocument::cleanChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QDocument::undoAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QDocument::redoAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QDocument::formatsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QDocument::contentsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QDocument::fontChanged(QFont _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void QDocument::formatsChange(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void QDocument::contentsChange(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void QDocument::changedText(int _t1, int _t2, int _t3, int _t4, const QString & _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 9
void QDocument::widthChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void QDocument::heightChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void QDocument::sizeChanged(const QSize & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void QDocument::lineCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void QDocument::visualLineCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void QDocument::lineDeleted(QDocumentLineHandle * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 16
void QDocument::lineRemoved(QDocumentLineHandle * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void QDocument::linesRemoved(QDocumentLineHandle * _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2, _t3);
}

// SIGNAL 18
void QDocument::markChanged(QDocumentLineHandle * _t1, int _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1, _t2, _t3);
}

// SIGNAL 19
void QDocument::lineEndingChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void QDocument::slowOperationStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void QDocument::slowOperationEnded()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void QDocument::bookmarkRemoved(QDocumentLineHandle * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void QDocument::bookmarkAdded(QDocumentLineHandle * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1, _t2);
}
QT_WARNING_POP
