/********************************************************************************
** Form generated from reading UI file 'cleandialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CLEANDIALOG_H
#define UI_CLEANDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_CleanDialog
{
public:
    QGridLayout *gridLayout;
    QLabel *label_2;
    QComboBox *cbScope;
    QLabel *label;
    QHBoxLayout *horizontalLayout;
    QLineEdit *leExtensions;
    QPushButton *pbResetExtensions;
    QLabel *label_3;
    QDialogButtonBox *buttonBox;
    QListWidget *lwFiles;
    QLabel *label_4;

    void setupUi(QDialog *CleanDialog)
    {
        if (CleanDialog->objectName().isEmpty())
            CleanDialog->setObjectName("CleanDialog");
        CleanDialog->resize(492, 285);
        gridLayout = new QGridLayout(CleanDialog);
        gridLayout->setObjectName("gridLayout");
        label_2 = new QLabel(CleanDialog);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        cbScope = new QComboBox(CleanDialog);
        cbScope->setObjectName("cbScope");

        gridLayout->addWidget(cbScope, 1, 1, 1, 1);

        label = new QLabel(CleanDialog);
        label->setObjectName("label");

        gridLayout->addWidget(label, 2, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        leExtensions = new QLineEdit(CleanDialog);
        leExtensions->setObjectName("leExtensions");

        horizontalLayout->addWidget(leExtensions);

        pbResetExtensions = new QPushButton(CleanDialog);
        pbResetExtensions->setObjectName("pbResetExtensions");
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images-ng/edit-undo.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        pbResetExtensions->setIcon(icon);

        horizontalLayout->addWidget(pbResetExtensions);


        gridLayout->addLayout(horizontalLayout, 2, 1, 1, 1);

        label_3 = new QLabel(CleanDialog);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 0, 0, 1, 2);

        buttonBox = new QDialogButtonBox(CleanDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 4, 0, 1, 2);

        lwFiles = new QListWidget(CleanDialog);
        lwFiles->setObjectName("lwFiles");
        lwFiles->setEditTriggers(QAbstractItemView::NoEditTriggers);
        lwFiles->setProperty("showDropIndicator", QVariant(false));
        lwFiles->setSelectionMode(QAbstractItemView::NoSelection);

        gridLayout->addWidget(lwFiles, 3, 1, 1, 1);

        label_4 = new QLabel(CleanDialog);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        gridLayout->addWidget(label_4, 3, 0, 1, 1);

        QWidget::setTabOrder(buttonBox, cbScope);
        QWidget::setTabOrder(cbScope, leExtensions);
        QWidget::setTabOrder(leExtensions, pbResetExtensions);

        retranslateUi(CleanDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CleanDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CleanDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CleanDialog);
    } // setupUi

    void retranslateUi(QDialog *CleanDialog)
    {
        CleanDialog->setWindowTitle(QCoreApplication::translate("CleanDialog", "Clean", nullptr));
        label_2->setText(QCoreApplication::translate("CleanDialog", "Scope", nullptr));
        label->setText(QCoreApplication::translate("CleanDialog", "File Extensions", nullptr));
#if QT_CONFIG(tooltip)
        pbResetExtensions->setToolTip(QCoreApplication::translate("CleanDialog", "Restore default", nullptr));
#endif // QT_CONFIG(tooltip)
        pbResetExtensions->setText(QString());
        label_3->setText(QCoreApplication::translate("CleanDialog", "Delete the auxiliary files generated by LaTeX:", nullptr));
        label_4->setText(QCoreApplication::translate("CleanDialog", "Files to Delete", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CleanDialog: public Ui_CleanDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CLEANDIALOG_H
