/****************************************************************************
** Meta object code from reading C++ file 'buildmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../texstudio-4.9.5/src/buildmanager.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'buildmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12BuildManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto BuildManager::qt_create_metaobjectdata<qt_meta_tag_ZN12BuildManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BuildManager",
        "processNotification",
        "",
        "message",
        "clearLogs",
        "previewAvailable",
        "filename",
        "PreviewSource",
        "source",
        "commandLineRequested",
        "cmdId",
        "QString*",
        "result",
        "bool*",
        "user",
        "runInternalCommand",
        "QFileInfo",
        "mainfile",
        "options",
        "latexCompiled",
        "LatexCompileResult*",
        "rerun",
        "beginRunningCommands",
        "commandMain",
        "latex",
        "pdf",
        "asyncPdf",
        "beginRunningSubCommand",
        "ProcessX*",
        "p",
        "subCommand",
        "RunCommandFlags",
        "flags",
        "endRunningSubCommand",
        "endRunningCommands",
        "buildRunning",
        "c",
        "runCommand",
        "unparsedCommandLine",
        "mainFile",
        "currentFile",
        "currentLine",
        "buffer",
        "QTextCodec*",
        "codecForBuffer",
        "errorMsg",
        "killCurrentProcess",
        "singleInstanceCompleted",
        "status",
        "preamblePrecompileCompleted",
        "latexPreviewCompleted",
        "dvi2psPreviewCompleted",
        "conversionPreviewCompleted",
        "PreviewLatexCompleted",
        "commandLineRequestedDefault",
        "runInternalCommandThroughProcessX",
        "emitEndRunningSubCommandFromProcessX",
        "firstProcessOfDirectExpansion",
        "command",
        "nonstop",
        "newProcessInternal",
        "fullCommandLine",
        "singleInstance",
        "waitForProcess",
        "waitingForProcess",
        "isCommandDirectlyDefined",
        "id",
        "getCommandLine"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'processNotification'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'clearLogs'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previewAvailable'
        QtMocHelpers::SignalData<void(const QString &, const PreviewSource &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'commandLineRequested'
        QtMocHelpers::SignalData<void(const QString &, QString *, bool *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { 0x80000000 | 11, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Signal 'commandLineRequested'
        QtMocHelpers::SignalData<void(const QString &, QString *)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Signal 'runInternalCommand'
        QtMocHelpers::SignalData<void(const QString &, const QFileInfo &, const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { 0x80000000 | 16, 17 }, { QMetaType::QString, 18 },
        }}),
        // Signal 'latexCompiled'
        QtMocHelpers::SignalData<void(LatexCompileResult *)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Signal 'beginRunningCommands'
        QtMocHelpers::SignalData<void(const QString &, bool, bool, bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 }, { QMetaType::Bool, 24 }, { QMetaType::Bool, 25 }, { QMetaType::Bool, 26 },
        }}),
        // Signal 'beginRunningSubCommand'
        QtMocHelpers::SignalData<void(ProcessX *, const QString &, const QString &, const RunCommandFlags &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 }, { QMetaType::QString, 23 }, { QMetaType::QString, 30 }, { 0x80000000 | 31, 32 },
        }}),
        // Signal 'endRunningSubCommand'
        QtMocHelpers::SignalData<void(ProcessX *, const QString &, const QString &, const RunCommandFlags &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 }, { QMetaType::QString, 23 }, { QMetaType::QString, 30 }, { 0x80000000 | 31, 32 },
        }}),
        // Signal 'endRunningCommands'
        QtMocHelpers::SignalData<void(const QString &, bool, bool, bool)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 }, { QMetaType::Bool, 24 }, { QMetaType::Bool, 25 }, { QMetaType::Bool, 26 },
        }}),
        // Signal 'buildRunning'
        QtMocHelpers::SignalData<void(bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 36 },
        }}),
        // Slot 'runCommand'
        QtMocHelpers::SlotData<bool(const QString &, const QFileInfo &, const QFileInfo &, int, QString *, QTextCodec *, QString *)>(37, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 38 }, { 0x80000000 | 16, 39 }, { 0x80000000 | 16, 40 }, { QMetaType::Int, 41 },
            { 0x80000000 | 11, 42 }, { 0x80000000 | 43, 44 }, { 0x80000000 | 11, 45 },
        }}),
        // Slot 'runCommand'
        QtMocHelpers::SlotData<bool(const QString &, const QFileInfo &, const QFileInfo &, int, QString *, QTextCodec *)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 38 }, { 0x80000000 | 16, 39 }, { 0x80000000 | 16, 40 }, { QMetaType::Int, 41 },
            { 0x80000000 | 11, 42 }, { 0x80000000 | 43, 44 },
        }}),
        // Slot 'runCommand'
        QtMocHelpers::SlotData<bool(const QString &, const QFileInfo &, const QFileInfo &, int, QString *)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 38 }, { 0x80000000 | 16, 39 }, { 0x80000000 | 16, 40 }, { QMetaType::Int, 41 },
            { 0x80000000 | 11, 42 },
        }}),
        // Slot 'runCommand'
        QtMocHelpers::SlotData<bool(const QString &, const QFileInfo &, const QFileInfo &, int)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 38 }, { 0x80000000 | 16, 39 }, { 0x80000000 | 16, 40 }, { QMetaType::Int, 41 },
        }}),
        // Slot 'runCommand'
        QtMocHelpers::SlotData<bool(const QString &, const QFileInfo &, const QFileInfo &)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 38 }, { 0x80000000 | 16, 39 }, { 0x80000000 | 16, 40 },
        }}),
        // Slot 'runCommand'
        QtMocHelpers::SlotData<bool(const QString &, const QFileInfo &)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 38 }, { 0x80000000 | 16, 39 },
        }}),
        // Slot 'killCurrentProcess'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'singleInstanceCompleted'
        QtMocHelpers::SlotData<void(int)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Slot 'preamblePrecompileCompleted'
        QtMocHelpers::SlotData<void(int)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Slot 'latexPreviewCompleted'
        QtMocHelpers::SlotData<void(int)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Slot 'dvi2psPreviewCompleted'
        QtMocHelpers::SlotData<void(int)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Slot 'conversionPreviewCompleted'
        QtMocHelpers::SlotData<void(int)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Slot 'PreviewLatexCompleted'
        QtMocHelpers::SlotData<void(int)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Slot 'commandLineRequestedDefault'
        QtMocHelpers::SlotData<void(const QString &, QString *, bool *)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { 0x80000000 | 11, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Slot 'runInternalCommandThroughProcessX'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'emitEndRunningSubCommandFromProcessX'
        QtMocHelpers::SlotData<void(int)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Method 'firstProcessOfDirectExpansion'
        QtMocHelpers::MethodData<ProcessX *(const QString &, const QFileInfo &, const QFileInfo &, int, bool)>(57, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::QString, 58 }, { 0x80000000 | 16, 17 }, { 0x80000000 | 16, 40 }, { QMetaType::Int, 41 },
            { QMetaType::Bool, 59 },
        }}),
        // Method 'firstProcessOfDirectExpansion'
        QtMocHelpers::MethodData<ProcessX *(const QString &, const QFileInfo &, const QFileInfo &, int)>(57, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 28, {{
            { QMetaType::QString, 58 }, { 0x80000000 | 16, 17 }, { 0x80000000 | 16, 40 }, { QMetaType::Int, 41 },
        }}),
        // Method 'firstProcessOfDirectExpansion'
        QtMocHelpers::MethodData<ProcessX *(const QString &, const QFileInfo &, const QFileInfo &)>(57, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 28, {{
            { QMetaType::QString, 58 }, { 0x80000000 | 16, 17 }, { 0x80000000 | 16, 40 },
        }}),
        // Method 'firstProcessOfDirectExpansion'
        QtMocHelpers::MethodData<ProcessX *(const QString &, const QFileInfo &)>(57, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 28, {{
            { QMetaType::QString, 58 }, { 0x80000000 | 16, 17 },
        }}),
        // Method 'newProcessInternal'
        QtMocHelpers::MethodData<ProcessX *(const QString &, const QFileInfo &, bool)>(60, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::QString, 61 }, { 0x80000000 | 16, 39 }, { QMetaType::Bool, 62 },
        }}),
        // Method 'newProcessInternal'
        QtMocHelpers::MethodData<ProcessX *(const QString &, const QFileInfo &)>(60, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 28, {{
            { QMetaType::QString, 61 }, { 0x80000000 | 16, 39 },
        }}),
        // Method 'waitForProcess'
        QtMocHelpers::MethodData<bool(ProcessX *)>(63, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Method 'waitingForProcess'
        QtMocHelpers::MethodData<bool() const>(64, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'isCommandDirectlyDefined'
        QtMocHelpers::MethodData<bool(const QString &) const>(65, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 66 },
        }}),
        // Method 'getCommandLine'
        QtMocHelpers::MethodData<QString(const QString &, bool *)>(67, 2, QMC::AccessPrivate, QMetaType::QString, {{
            { QMetaType::QString, 66 }, { 0x80000000 | 13, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BuildManager, qt_meta_tag_ZN12BuildManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BuildManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12BuildManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12BuildManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12BuildManagerE_t>.metaTypes,
    nullptr
} };

void BuildManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BuildManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->processNotification((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->clearLogs(); break;
        case 2: _t->previewAvailable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<PreviewSource>>(_a[2]))); break;
        case 3: _t->commandLineRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool*>>(_a[3]))); break;
        case 4: _t->commandLineRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString*>>(_a[2]))); break;
        case 5: _t->runInternalCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 6: _t->latexCompiled((*reinterpret_cast<std::add_pointer_t<LatexCompileResult*>>(_a[1]))); break;
        case 7: _t->beginRunningCommands((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 8: _t->beginRunningSubCommand((*reinterpret_cast<std::add_pointer_t<ProcessX*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<RunCommandFlags>>(_a[4]))); break;
        case 9: _t->endRunningSubCommand((*reinterpret_cast<std::add_pointer_t<ProcessX*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<RunCommandFlags>>(_a[4]))); break;
        case 10: _t->endRunningCommands((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 11: _t->buildRunning((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: { bool _r = _t->runCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString*>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QTextCodec*>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString*>>(_a[7])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->runCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString*>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QTextCodec*>>(_a[6])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->runCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString*>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->runCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->runCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->runCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->killCurrentProcess(); break;
        case 19: _t->singleInstanceCompleted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->preamblePrecompileCompleted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->latexPreviewCompleted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->dvi2psPreviewCompleted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->conversionPreviewCompleted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->PreviewLatexCompleted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->commandLineRequestedDefault((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool*>>(_a[3]))); break;
        case 26: _t->runInternalCommandThroughProcessX(); break;
        case 27: _t->emitEndRunningSubCommandFromProcessX((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: { ProcessX* _r = _t->firstProcessOfDirectExpansion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])));
            if (_a[0]) *reinterpret_cast<ProcessX**>(_a[0]) = std::move(_r); }  break;
        case 29: { ProcessX* _r = _t->firstProcessOfDirectExpansion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<ProcessX**>(_a[0]) = std::move(_r); }  break;
        case 30: { ProcessX* _r = _t->firstProcessOfDirectExpansion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[3])));
            if (_a[0]) *reinterpret_cast<ProcessX**>(_a[0]) = std::move(_r); }  break;
        case 31: { ProcessX* _r = _t->firstProcessOfDirectExpansion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2])));
            if (_a[0]) *reinterpret_cast<ProcessX**>(_a[0]) = std::move(_r); }  break;
        case 32: { ProcessX* _r = _t->newProcessInternal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<ProcessX**>(_a[0]) = std::move(_r); }  break;
        case 33: { ProcessX* _r = _t->newProcessInternal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2])));
            if (_a[0]) *reinterpret_cast<ProcessX**>(_a[0]) = std::move(_r); }  break;
        case 34: { bool _r = _t->waitForProcess((*reinterpret_cast<std::add_pointer_t<ProcessX*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 35: { bool _r = _t->waitingForProcess();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->isCommandDirectlyDefined((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { QString _r = _t->getCommandLine((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ProcessX* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ProcessX* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ProcessX* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BuildManager::*)(const QString & )>(_a, &BuildManager::processNotification, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BuildManager::*)()>(_a, &BuildManager::clearLogs, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BuildManager::*)(const QString & , const PreviewSource & )>(_a, &BuildManager::previewAvailable, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BuildManager::*)(const QString & , QString * , bool * )>(_a, &BuildManager::commandLineRequested, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BuildManager::*)(const QString & , const QFileInfo & , const QString & )>(_a, &BuildManager::runInternalCommand, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BuildManager::*)(LatexCompileResult * )>(_a, &BuildManager::latexCompiled, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (BuildManager::*)(const QString & , bool , bool , bool )>(_a, &BuildManager::beginRunningCommands, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (BuildManager::*)(ProcessX * , const QString & , const QString & , const RunCommandFlags & )>(_a, &BuildManager::beginRunningSubCommand, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (BuildManager::*)(ProcessX * , const QString & , const QString & , const RunCommandFlags & )>(_a, &BuildManager::endRunningSubCommand, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (BuildManager::*)(const QString & , bool , bool , bool )>(_a, &BuildManager::endRunningCommands, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (BuildManager::*)(bool )>(_a, &BuildManager::buildRunning, 11))
            return;
    }
}

const QMetaObject *BuildManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BuildManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12BuildManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BuildManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    return _id;
}

// SIGNAL 0
void BuildManager::processNotification(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BuildManager::clearLogs()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void BuildManager::previewAvailable(const QString & _t1, const PreviewSource & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void BuildManager::commandLineRequested(const QString & _t1, QString * _t2, bool * _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void BuildManager::runInternalCommand(const QString & _t1, const QFileInfo & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void BuildManager::latexCompiled(LatexCompileResult * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void BuildManager::beginRunningCommands(const QString & _t1, bool _t2, bool _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 8
void BuildManager::beginRunningSubCommand(ProcessX * _t1, const QString & _t2, const QString & _t3, const RunCommandFlags & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 9
void BuildManager::endRunningSubCommand(ProcessX * _t1, const QString & _t2, const QString & _t3, const RunCommandFlags & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 10
void BuildManager::endRunningCommands(const QString & _t1, bool _t2, bool _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 11
void BuildManager::buildRunning(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN8ProcessXE_t {};
} // unnamed namespace

template <> constexpr inline auto ProcessX::qt_create_metaobjectdata<qt_meta_tag_ZN8ProcessXE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProcessX",
        "startedX",
        "",
        "processNotification",
        "message",
        "standardOutputRead",
        "data",
        "standardErrorRead",
        "processFinished",
        "onStarted",
        "onError",
        "QProcess::ProcessError",
        "error",
        "onFinished",
        "readFromStandardOutput",
        "readFromStandardError",
        "force",
        "getStdout",
        "exitStatus",
        "exitCode",
        "readAllStandardOutputStr",
        "readAllStandardErrorStr",
        "waitForFinished",
        "msecs"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'startedX'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'processNotification'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'standardOutputRead'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'standardErrorRead'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'processFinished'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onStarted'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onError'
        QtMocHelpers::SlotData<void(QProcess::ProcessError)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'onFinished'
        QtMocHelpers::SlotData<void(int)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'readFromStandardOutput'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'readFromStandardError'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'readFromStandardError'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Method 'getStdout'
        QtMocHelpers::MethodData<QString()>(17, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'exitStatus'
        QtMocHelpers::MethodData<int() const>(18, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'exitCode'
        QtMocHelpers::MethodData<int() const>(19, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'readAllStandardOutputStr'
        QtMocHelpers::MethodData<QString()>(20, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'readAllStandardErrorStr'
        QtMocHelpers::MethodData<QString()>(21, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'waitForFinished'
        QtMocHelpers::MethodData<bool(int)>(22, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 23 },
        }}),
        // Method 'waitForFinished'
        QtMocHelpers::MethodData<bool()>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProcessX, qt_meta_tag_ZN8ProcessXE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ProcessX::staticMetaObject = { {
    QMetaObject::SuperData::link<QProcess::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ProcessXE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ProcessXE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8ProcessXE_t>.metaTypes,
    nullptr
} };

void ProcessX::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProcessX *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->startedX(); break;
        case 1: _t->processNotification((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->standardOutputRead((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->standardErrorRead((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->processFinished(); break;
        case 5: _t->onStarted(); break;
        case 6: _t->onError((*reinterpret_cast<std::add_pointer_t<QProcess::ProcessError>>(_a[1]))); break;
        case 7: _t->onFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->readFromStandardOutput(); break;
        case 9: _t->readFromStandardError((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->readFromStandardError(); break;
        case 11: { QString _r = _t->getStdout();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { int _r = _t->exitStatus();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 13: { int _r = _t->exitCode();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->readAllStandardOutputStr();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { QString _r = _t->readAllStandardErrorStr();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->waitForFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->waitForFinished();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProcessX::*)()>(_a, &ProcessX::startedX, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessX::*)(const QString & )>(_a, &ProcessX::processNotification, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessX::*)(const QString & )>(_a, &ProcessX::standardOutputRead, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessX::*)(const QString & )>(_a, &ProcessX::standardErrorRead, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessX::*)()>(_a, &ProcessX::processFinished, 4))
            return;
    }
}

const QMetaObject *ProcessX::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProcessX::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ProcessXE_t>.strings))
        return static_cast<void*>(this);
    return QProcess::qt_metacast(_clname);
}

int ProcessX::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QProcess::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void ProcessX::startedX()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ProcessX::processNotification(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ProcessX::standardOutputRead(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ProcessX::standardErrorRead(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ProcessX::processFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
