/****************************************************************************
** Meta object code from reading C++ file 'collaborationmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../texstudio-4.9.5/src/collaborationmanager.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'collaborationmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20CollaborationManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto CollaborationManager::qt_create_metaobjectdata<qt_meta_tag_ZN20CollaborationManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CollaborationManager",
        "changesReceived",
        "",
        "QDocumentCursor",
        "cursor",
        "changes",
        "userName",
        "cursorMoved",
        "userId",
        "cursorRemoved",
        "LatexDocument*",
        "doc",
        "clientSuccessfullyStarted",
        "msg",
        "guestServerSuccessfullyStarted",
        "hostServerSuccessfullyStarted",
        "collabClientFinished",
        "exitCode",
        "m_errorMessage",
        "sendChanges",
        "fileName",
        "startLine",
        "startCol",
        "endLine",
        "endCol",
        "rev",
        "sendCursor",
        "readyCollabClientStandardOutput",
        "readyCollabServerStandardOutput",
        "clientFinished",
        "QProcess::ExitStatus",
        "exitStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changesReceived'
        QtMocHelpers::SignalData<void(QDocumentCursor, const QString, const QString)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'cursorMoved'
        QtMocHelpers::SignalData<void(QDocumentCursor, const QString)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'cursorRemoved'
        QtMocHelpers::SignalData<void(LatexDocument *, const QString)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'clientSuccessfullyStarted'
        QtMocHelpers::SignalData<void(QString)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'guestServerSuccessfullyStarted'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hostServerSuccessfullyStarted'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'collabClientFinished'
        QtMocHelpers::SignalData<void(int, QString)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'sendChanges'
        QtMocHelpers::SlotData<void(QDocumentCursor, const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'sendChanges'
        QtMocHelpers::SlotData<void(QString, int, int, int, int, const QString &, qint64)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { QMetaType::Int, 21 }, { QMetaType::Int, 22 }, { QMetaType::Int, 23 },
            { QMetaType::Int, 24 }, { QMetaType::QString, 5 }, { QMetaType::LongLong, 25 },
        }}),
        // Slot 'sendCursor'
        QtMocHelpers::SlotData<void(QDocumentCursor)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'readyCollabClientStandardOutput'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'readyCollabServerStandardOutput'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clientFinished'
        QtMocHelpers::SlotData<void(int, QProcess::ExitStatus)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { 0x80000000 | 30, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CollaborationManager, qt_meta_tag_ZN20CollaborationManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CollaborationManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20CollaborationManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20CollaborationManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20CollaborationManagerE_t>.metaTypes,
    nullptr
} };

void CollaborationManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CollaborationManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changesReceived((*reinterpret_cast<std::add_pointer_t<QDocumentCursor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: _t->cursorMoved((*reinterpret_cast<std::add_pointer_t<QDocumentCursor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->cursorRemoved((*reinterpret_cast<std::add_pointer_t<LatexDocument*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->clientSuccessfullyStarted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->guestServerSuccessfullyStarted(); break;
        case 5: _t->hostServerSuccessfullyStarted(); break;
        case 6: _t->collabClientFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->sendChanges((*reinterpret_cast<std::add_pointer_t<QDocumentCursor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->sendChanges((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[7]))); break;
        case 9: _t->sendCursor((*reinterpret_cast<std::add_pointer_t<QDocumentCursor>>(_a[1]))); break;
        case 10: _t->readyCollabClientStandardOutput(); break;
        case 11: _t->readyCollabServerStandardOutput(); break;
        case 12: _t->clientFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QProcess::ExitStatus>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocumentCursor >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocumentCursor >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LatexDocument* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocumentCursor >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocumentCursor >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CollaborationManager::*)(QDocumentCursor , const QString , const QString )>(_a, &CollaborationManager::changesReceived, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollaborationManager::*)(QDocumentCursor , const QString )>(_a, &CollaborationManager::cursorMoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollaborationManager::*)(LatexDocument * , const QString )>(_a, &CollaborationManager::cursorRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollaborationManager::*)(QString )>(_a, &CollaborationManager::clientSuccessfullyStarted, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollaborationManager::*)()>(_a, &CollaborationManager::guestServerSuccessfullyStarted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollaborationManager::*)()>(_a, &CollaborationManager::hostServerSuccessfullyStarted, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollaborationManager::*)(int , QString )>(_a, &CollaborationManager::collabClientFinished, 6))
            return;
    }
}

const QMetaObject *CollaborationManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CollaborationManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20CollaborationManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CollaborationManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void CollaborationManager::changesReceived(QDocumentCursor _t1, const QString _t2, const QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void CollaborationManager::cursorMoved(QDocumentCursor _t1, const QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void CollaborationManager::cursorRemoved(LatexDocument * _t1, const QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void CollaborationManager::clientSuccessfullyStarted(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void CollaborationManager::guestServerSuccessfullyStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void CollaborationManager::hostServerSuccessfullyStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void CollaborationManager::collabClientFinished(int _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}
QT_WARNING_POP
