/****************************************************************************
** Meta object code from reading C++ file 'scriptengine.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../texstudio-4.9.5/src/scriptengine.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scriptengine.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12scriptengineE_t {};
} // unnamed namespace

template <> constexpr inline auto scriptengine::qt_create_metaobjectdata<qt_meta_tag_ZN12scriptengineE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "scriptengine",
        "getLineTokens",
        "QJSValue",
        "",
        "lineNr",
        "insertSnippet",
        "arg",
        "replaceSelectedText",
        "replacementText",
        "options",
        "searchFunction",
        "searchFor",
        "arg1",
        "arg2",
        "arg3",
        "replaceFunction",
        "alert",
        "message",
        "information",
        "critical",
        "warning",
        "confirm",
        "confirmWarning",
        "debug",
        "crash_sigsegv",
        "crash_sigfpe",
        "crash_stack",
        "crash_loop",
        "crash_throw",
        "system",
        "ProcessX*",
        "commandline",
        "workingDirectory",
        "writeFile",
        "filename",
        "content",
        "readFile",
        "QVariant",
        "hasPersistent",
        "name",
        "setPersistent",
        "value",
        "getPersistent",
        "registerAsBackgroundScript",
        "setTimeout",
        "fun",
        "timeout",
        "save",
        "fn",
        "saveCopy",
        "fileName",
        "runTimed"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'getLineTokens'
        QtMocHelpers::SlotData<QJSValue(int)>(1, 3, QMC::AccessProtected, 0x80000000 | 2, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'insertSnippet'
        QtMocHelpers::SlotData<void(const QString &)>(5, 3, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'replaceSelectedText'
        QtMocHelpers::SlotData<QJSValue(QJSValue, QJSValue)>(7, 3, QMC::AccessProtected, 0x80000000 | 2, {{
            { 0x80000000 | 2, 8 }, { 0x80000000 | 2, 9 },
        }}),
        // Slot 'replaceSelectedText'
        QtMocHelpers::SlotData<QJSValue(QJSValue)>(7, 3, QMC::AccessProtected | QMC::MethodCloned, 0x80000000 | 2, {{
            { 0x80000000 | 2, 8 },
        }}),
        // Slot 'searchFunction'
        QtMocHelpers::SlotData<QJSValue(QJSValue, QJSValue, QJSValue, QJSValue)>(10, 3, QMC::AccessProtected, 0x80000000 | 2, {{
            { 0x80000000 | 2, 11 }, { 0x80000000 | 2, 12 }, { 0x80000000 | 2, 13 }, { 0x80000000 | 2, 14 },
        }}),
        // Slot 'searchFunction'
        QtMocHelpers::SlotData<QJSValue(QJSValue, QJSValue, QJSValue)>(10, 3, QMC::AccessProtected | QMC::MethodCloned, 0x80000000 | 2, {{
            { 0x80000000 | 2, 11 }, { 0x80000000 | 2, 12 }, { 0x80000000 | 2, 13 },
        }}),
        // Slot 'searchFunction'
        QtMocHelpers::SlotData<QJSValue(QJSValue, QJSValue)>(10, 3, QMC::AccessProtected | QMC::MethodCloned, 0x80000000 | 2, {{
            { 0x80000000 | 2, 11 }, { 0x80000000 | 2, 12 },
        }}),
        // Slot 'searchFunction'
        QtMocHelpers::SlotData<QJSValue(QJSValue)>(10, 3, QMC::AccessProtected | QMC::MethodCloned, 0x80000000 | 2, {{
            { 0x80000000 | 2, 11 },
        }}),
        // Slot 'replaceFunction'
        QtMocHelpers::SlotData<QJSValue(QJSValue, QJSValue, QJSValue, QJSValue)>(15, 3, QMC::AccessProtected, 0x80000000 | 2, {{
            { 0x80000000 | 2, 11 }, { 0x80000000 | 2, 12 }, { 0x80000000 | 2, 13 }, { 0x80000000 | 2, 14 },
        }}),
        // Slot 'replaceFunction'
        QtMocHelpers::SlotData<QJSValue(QJSValue, QJSValue, QJSValue)>(15, 3, QMC::AccessProtected | QMC::MethodCloned, 0x80000000 | 2, {{
            { 0x80000000 | 2, 11 }, { 0x80000000 | 2, 12 }, { 0x80000000 | 2, 13 },
        }}),
        // Slot 'replaceFunction'
        QtMocHelpers::SlotData<QJSValue(QJSValue, QJSValue)>(15, 3, QMC::AccessProtected | QMC::MethodCloned, 0x80000000 | 2, {{
            { 0x80000000 | 2, 11 }, { 0x80000000 | 2, 12 },
        }}),
        // Slot 'replaceFunction'
        QtMocHelpers::SlotData<QJSValue(QJSValue)>(15, 3, QMC::AccessProtected | QMC::MethodCloned, 0x80000000 | 2, {{
            { 0x80000000 | 2, 11 },
        }}),
        // Slot 'alert'
        QtMocHelpers::SlotData<void(const QString &)>(16, 3, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'information'
        QtMocHelpers::SlotData<void(const QString &)>(18, 3, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'critical'
        QtMocHelpers::SlotData<void(const QString &)>(19, 3, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'warning'
        QtMocHelpers::SlotData<void(const QString &)>(20, 3, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'confirm'
        QtMocHelpers::SlotData<bool(const QString &)>(21, 3, QMC::AccessProtected, QMetaType::Bool, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'confirmWarning'
        QtMocHelpers::SlotData<bool(const QString &)>(22, 3, QMC::AccessProtected, QMetaType::Bool, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'debug'
        QtMocHelpers::SlotData<void(const QString &)>(23, 3, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'crash_sigsegv'
        QtMocHelpers::SlotData<void()>(24, 3, QMC::AccessProtected, QMetaType::Void),
        // Slot 'crash_sigfpe'
        QtMocHelpers::SlotData<void()>(25, 3, QMC::AccessProtected, QMetaType::Void),
        // Slot 'crash_stack'
        QtMocHelpers::SlotData<void()>(26, 3, QMC::AccessProtected, QMetaType::Void),
        // Slot 'crash_loop'
        QtMocHelpers::SlotData<void()>(27, 3, QMC::AccessProtected, QMetaType::Void),
        // Slot 'crash_throw'
        QtMocHelpers::SlotData<void()>(28, 3, QMC::AccessProtected, QMetaType::Void),
        // Slot 'system'
        QtMocHelpers::SlotData<ProcessX *(const QString &, const QString &)>(29, 3, QMC::AccessProtected, 0x80000000 | 30, {{
            { QMetaType::QString, 31 }, { QMetaType::QString, 32 },
        }}),
        // Slot 'system'
        QtMocHelpers::SlotData<ProcessX *(const QString &)>(29, 3, QMC::AccessProtected | QMC::MethodCloned, 0x80000000 | 30, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'writeFile'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(33, 3, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 34 }, { QMetaType::QString, 35 },
        }}),
        // Slot 'readFile'
        QtMocHelpers::SlotData<QVariant(const QString &)>(36, 3, QMC::AccessProtected, 0x80000000 | 37, {{
            { QMetaType::QString, 34 },
        }}),
        // Slot 'hasPersistent'
        QtMocHelpers::SlotData<bool(const QString &)>(38, 3, QMC::AccessProtected, QMetaType::Bool, {{
            { QMetaType::QString, 39 },
        }}),
        // Slot 'setPersistent'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(40, 3, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 39 }, { 0x80000000 | 37, 41 },
        }}),
        // Slot 'getPersistent'
        QtMocHelpers::SlotData<QVariant(const QString &)>(42, 3, QMC::AccessProtected, 0x80000000 | 37, {{
            { QMetaType::QString, 39 },
        }}),
        // Slot 'registerAsBackgroundScript'
        QtMocHelpers::SlotData<void(const QString &)>(43, 3, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 39 },
        }}),
        // Slot 'registerAsBackgroundScript'
        QtMocHelpers::SlotData<void()>(43, 3, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setTimeout'
        QtMocHelpers::SlotData<bool(const QString &, const int)>(44, 3, QMC::AccessProtected, QMetaType::Bool, {{
            { QMetaType::QString, 45 }, { QMetaType::Int, 46 },
        }}),
        // Slot 'save'
        QtMocHelpers::SlotData<void(const QString)>(47, 3, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(47, 3, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void),
        // Slot 'saveCopy'
        QtMocHelpers::SlotData<void(const QString &)>(49, 3, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 50 },
        }}),
        // Slot 'runTimed'
        QtMocHelpers::SlotData<void(const QString)>(51, 3, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 45 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<scriptengine, qt_meta_tag_ZN12scriptengineE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject scriptengine::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12scriptengineE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12scriptengineE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12scriptengineE_t>.metaTypes,
    nullptr
} };

void scriptengine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<scriptengine *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QJSValue _r = _t->getLineTokens((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->insertSnippet((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: { QJSValue _r = _t->replaceSelectedText((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 3: { QJSValue _r = _t->replaceSelectedText((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 4: { QJSValue _r = _t->searchFunction((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 5: { QJSValue _r = _t->searchFunction((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 6: { QJSValue _r = _t->searchFunction((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 7: { QJSValue _r = _t->searchFunction((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 8: { QJSValue _r = _t->replaceFunction((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 9: { QJSValue _r = _t->replaceFunction((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 10: { QJSValue _r = _t->replaceFunction((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 11: { QJSValue _r = _t->replaceFunction((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->alert((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->information((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->critical((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->warning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: { bool _r = _t->confirm((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->confirmWarning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->debug((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->crash_sigsegv(); break;
        case 20: _t->crash_sigfpe(); break;
        case 21: _t->crash_stack(); break;
        case 22: _t->crash_loop(); break;
        case 23: _t->crash_throw(); break;
        case 24: { ProcessX* _r = _t->system((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<ProcessX**>(_a[0]) = std::move(_r); }  break;
        case 25: { ProcessX* _r = _t->system((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<ProcessX**>(_a[0]) = std::move(_r); }  break;
        case 26: _t->writeFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 27: { QVariant _r = _t->readFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->hasPersistent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->setPersistent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 30: { QVariant _r = _t->getPersistent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 31: _t->registerAsBackgroundScript((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 32: _t->registerAsBackgroundScript(); break;
        case 33: { bool _r = _t->setTimeout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->save((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 35: _t->save(); break;
        case 36: _t->saveCopy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 37: _t->runTimed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
            case 2:
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
            case 2:
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
}

const QMetaObject *scriptengine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *scriptengine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12scriptengineE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int scriptengine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN26UniversalInputDialogScriptE_t {};
} // unnamed namespace

template <> constexpr inline auto UniversalInputDialogScript::qt_create_metaobjectdata<qt_meta_tag_ZN26UniversalInputDialogScriptE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UniversalInputDialogScript",
        "add",
        "QWidget*",
        "",
        "QJSValue",
        "def",
        "description",
        "id",
        "execDialog",
        "getAll",
        "get",
        "QVariant",
        "parent"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'add'
        QtMocHelpers::SlotData<QWidget *(const QJSValue &, const QJSValue &, const QJSValue &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 4, 6 }, { 0x80000000 | 4, 7 },
        }}),
        // Slot 'add'
        QtMocHelpers::SlotData<QWidget *(const QJSValue &, const QJSValue &)>(1, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 4, 6 },
        }}),
        // Slot 'execDialog'
        QtMocHelpers::SlotData<QJSValue()>(8, 3, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'getAll'
        QtMocHelpers::SlotData<QJSValue()>(9, 3, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'get'
        QtMocHelpers::SlotData<QVariant(const QJSValue &)>(10, 3, QMC::AccessPublic, 0x80000000 | 11, {{
            { 0x80000000 | 4, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    using Constructor = QtMocHelpers::NoType;
    QtMocHelpers::UintData qt_constructors {
        QtMocHelpers::ConstructorData<Constructor(QWidget *)>(3, QMC::AccessPublic, {{
            { 0x80000000 | 2, 12 },
        }}),
        QtMocHelpers::ConstructorData<Constructor()>(3, QMC::AccessPublic | QMC::MethodCloned),
    };
    return QtMocHelpers::metaObjectData<UniversalInputDialogScript, qt_meta_tag_ZN26UniversalInputDialogScriptE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors);
}
Q_CONSTINIT const QMetaObject UniversalInputDialogScript::staticMetaObject = { {
    QMetaObject::SuperData::link<UniversalInputDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26UniversalInputDialogScriptE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26UniversalInputDialogScriptE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26UniversalInputDialogScriptE_t>.metaTypes,
    nullptr
} };

void UniversalInputDialogScript::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UniversalInputDialogScript *>(_o);
    if (_c == QMetaObject::CreateInstance) {
        switch (_id) {
        case 0: { UniversalInputDialogScript *_r = new UniversalInputDialogScript((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        case 1: { UniversalInputDialogScript *_r = new UniversalInputDialogScript();
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        default: break;
        }
    }
    if (_c == QMetaObject::ConstructInPlace) {
        switch (_id) {
        case 0: { new (_a[0]) UniversalInputDialogScript((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); } break;
        case 1: { new (_a[0]) UniversalInputDialogScript(); } break;
        default: break;
        }
    }
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QWidget* _r = _t->add((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QWidget**>(_a[0]) = std::move(_r); }  break;
        case 1: { QWidget* _r = _t->add((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QWidget**>(_a[0]) = std::move(_r); }  break;
        case 2: { QJSValue _r = _t->execDialog();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 3: { QJSValue _r = _t->getAll();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 4: { QVariant _r = _t->get((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
}

const QMetaObject *UniversalInputDialogScript::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UniversalInputDialogScript::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26UniversalInputDialogScriptE_t>.strings))
        return static_cast<void*>(this);
    return UniversalInputDialog::qt_metacast(_clname);
}

int UniversalInputDialogScript::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UniversalInputDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
